#include <qpixmap.h>
#include <qtooltip.h>
#include <klocale.h>
#include <kpopupmenu.h>

#include <iostream>


#include "netconf_tray.hh"
#include "pixmaps.hh"
#include "profile_manager.hh"


NetconfTray::NetconfTray (QWidget *parent, ProfileManager* manager)
  : KSystemTray(parent, 0)
{
  m_manager = manager;
  QPixmap* icon = ::GetSmallPlug ();
  setCaption( i18n("network configuration") );
  setPixmap( *icon);
  QToolTip::add(this, i18n("network") );

  QObject::connect (m_manager, SIGNAL (newProfileList ()), this, SLOT (slotRebuildList ()));
  QObject::connect (m_manager, SIGNAL (changedActiveProfile ()), this, SLOT (slotNewActive ()));
  QObject::connect (contextMenu (), SIGNAL (activated (int)), this, SLOT (slotActivate (int)));
  
  slotRebuildList ();
}

void NetconfTray::slotRebuildList ()
{
  std::cout << "rebuilding tray menu" << std::endl;
  KPopupMenu* m = contextMenu ();
  for (unsigned int i = 0; i < profile_mapping.size(); i++)
    m -> removeItem (profile_mapping [i]);
  profile_mapping.clear ();

  unsigned int profile_count = m_manager -> Profiles ().size ();
  for (unsigned int i = 0; i < profile_count; i++) {
    int new_item = m -> insertItem (m_manager -> getI18NProfileName (i), i, i);
    profile_mapping.push_back (new_item);
    // std::cout << new_item << std::endl;
  }
  std::cout << "done." << std::endl;
  slotNewActive ();
}

void NetconfTray::slotNewActive ()
{
  unsigned int profile_id = 0;
  unsigned int profile_count = m_manager -> Profiles ().size ();
  int active = m_manager -> ActiveProfileIndex ();

  KPopupMenu* m = contextMenu ();

  for (; profile_id < profile_count; profile_id++)
    m -> setItemChecked(profile_mapping[profile_id], ((int)profile_id == active)); 
}


void NetconfTray::slotActivate (int item)
{
  unsigned int profile_id = 0;
  unsigned int profile_count = m_manager -> Profiles ().size ();

  for (; profile_id < profile_count; profile_id++) {
    if (profile_mapping[profile_id] == item)
      break;
  }

  if (profile_id < profile_count) {
    if ((int)profile_id != m_manager -> ActiveProfileIndex()) {
      std::cout << "activation of profile " << m_manager -> Profiles() [profile_id] << " through systemtray" << std::endl;
      m_manager -> ActivateProfile (profile_id);
    } else {
      std::cout << "deactivate profile " << m_manager -> Profiles() [profile_id] << " through systemtray" << std::endl;
      m_manager -> DeactivateProfile ();
    }
  }
  
}
