#include "wireless_tab.hh"

WirelessTab::WirelessTab (QWidget* parent, network_config::WirelessSubsection* subsection)
  : QButtonGroup (parent)
{
  setColumnLayout (2, Qt::Horizontal);
  config = 0;

  mode_label = new QLabel (this);
  mode_label -> setText ("Modus");//("mode");
  mode =  new QComboBox (this);
  mode -> insertItem ("managed");
  mode -> insertItem ("ad-hoc");


  channel_label = new QLabel (this);
  channel_label -> setText ("Kanal"); //("channel");
  // TODO: get iwlist <if> channel
  channel = new QSpinBox (1, 14, 1, this);

  essid_check = new QCheckBox (this);
  essid_check -> setText ("Essid"); // ("essid");
  essid = new KLineEdit ("", this);

  key_check = new QCheckBox (this);
  key_check -> setText ("Passwort"); // ("password");
  key = new KLineEdit ("", this);
  key -> setEchoMode (QLineEdit::Password);

  QObject::connect (mode, SIGNAL (activated (int)), this, SLOT (setMode(int)));
  QObject::connect (channel, SIGNAL (valueChanged (int)), this, SLOT (setChannel(int)));
  QObject::connect (essid, SIGNAL (textChanged (const QString&)), this, SLOT (setEssid(const QString&)));
  QObject::connect (essid_check, SIGNAL (toggled (bool)), this, SLOT (enableEssid (bool)));
  QObject::connect (key, SIGNAL (textChanged (const QString&)), this, SLOT (setKey(const QString&)));
  QObject::connect (key_check, SIGNAL (toggled (bool)), this, SLOT (enableKey (bool)));

  NewConfig (subsection);
}

void WirelessTab::NewConfig (network_config::WirelessSubsection* subsection)
{
  config = subsection;

  std::cout << "new wireless config" << std::endl;

  mode -> setCurrentItem (config -> Mode () -> mode);
  setMode (mode -> currentItem ());
  channel -> setValue (config -> Channel () -> channel);

  essid -> setText (config -> Essid () -> essid.c_str ());
  essid_check -> setChecked (config -> Essid () -> essid != "");
  enableEssid (essid_check -> isChecked ());
  
  key -> setText (config -> Key () -> key.c_str ());
  key_check -> setChecked (config -> Key () -> key != "");
  enableKey (key_check -> isChecked ());
}


void WirelessTab::setMode (int index)
{
  network_config::ModeLine* ml = config -> Mode ();
  ml -> mode = (index == 0) ? network_config::ModeLine::managed : network_config::ModeLine::adhoc;
  ml -> Set ();
  std::cout << ml -> line << std::endl;
  channel -> setEnabled (index != network_config::ModeLine::managed);
}

void WirelessTab::setChannel (int new_channel)
{
  network_config::ChannelLine* cl = config -> Channel ();
  cl -> channel = new_channel;
  cl -> Set ();
  std::cout << cl -> line << std::endl;
}

void WirelessTab::setEssid (const QString& new_id)
{
  network_config::EssidLine* el = config -> Essid ();
  el -> essid = new_id;
  el -> Set ();
  std::cout << el -> line << std::endl;
}

void WirelessTab::setKey (const QString& new_pass)
{
  network_config::KeyLine* kl = config -> Key ();
  kl -> key = new_pass;
  kl -> Set ();
  std::cout << kl -> line << std::endl;
}

void WirelessTab::enableEssid (bool state)
{
  network_config::EssidLine* el = config -> Essid ();
  el -> essid = (state) ? essid -> text () : "";
  el -> Set ();
  std::cout << el -> line << std::endl;
  essid -> setEnabled (state);
}

void WirelessTab::enableKey (bool state)
{
  network_config::KeyLine* kl = config -> Key ();
  kl -> key = (state) ? key -> text () : "";
  kl -> Set ();
  std::cout << kl -> line << std::endl;
  key -> setEnabled (state);
}
